@@ -198,6 +198,14 @@ class MDict(dict):
             result = MDict(self, key, **result)
         return result
 
+    def get(self, key, default=None):
+        result = dict.get(self, key, default)
+        if isinstance(result, list):
+            result = MList(result, self, key)
+        if isinstance(result, MDict):
+            result = MDict(self, key, **result)
+        return result
+
     def _update_delta(self):
         if isinstance(self.__parent, MObject):
             setattr(self.__parent, self.__key, dict(self))
@@ -279,7 +287,7 @@ class MObject(object):
 
         self._m__data = {}
         self._m__delta = {}
-        self._m__is_new = is_new
+        self._m__is_new = True
         self._m__relations = {}
 
         if data:
@@ -289,6 +297,8 @@ class MObject(object):
             for k, v in kwargs.iteritems():
                 setattr(self, k, v)
 
+        self._m__is_new = is_new
+
     def intialize(self):
         """ Called after the ``__init__`` method. Override this
         in your models to do any preprocessing you want at load time.
@@ -326,6 +336,8 @@ class MObject(object):
         # TODO: move this to the BelongsTo class
         if k in self.BELONGS_TO:
             related, foreign_key, key2 = BelongsTo.parse_attrs(self, self.BELONGS_TO[k], k)
+            if isinstance(v, BelongsTo):
+                v = v._rel__data
             if isinstance(v, MObject):
                 self._m__relations[k] = BelongsTo(v, self, related, k, foreign_key)
                 k = key2
@@ -359,7 +371,6 @@ class MObject(object):
         if not raw:
             raw_k = k
             if k in self.BELONGS_TO and (k not in self._m__relations or not isinstance(self._m__relations[k], BelongsTo)):
-                print 'loading', k
                 self._m__relations[k] = BelongsTo.load(self, k, self.BELONGS_TO[k])
             elif k in self.HAS_MANY and (k not in self._m__relations or not isinstance(self._m__relations[k], HasMany)):
                 self._m__relations[k] = HasMany.load(self, k, self.HAS_MANY[k])
@@ -372,8 +383,7 @@ class MObject(object):
         if not raw and k in self._m__relations:
             val = self._m__relations[k]
         else:
-            # TODO: catch KeyError and throw appropriate exception
-            val = self._m__data.get(k, default) if default is not None else self._m__data[k]
+            val = self._m__data.get(k, default)
 
         if isinstance(val, list):
             val = MList(val, self, k)
@@ -437,7 +447,6 @@ class MObject(object):
             doc['$set']['date_modified'] = datetime.now()
 
         collection = self._get_collection()
-        logging.info(collection.full_name, 'update', query, doc)
         response = collection.update(query, doc, **kwargs)
 
         # TODO: Check if a safe write and only clear delta if success
@@ -477,7 +486,6 @@ class MObject(object):
             self.date_modified = now
 
         collection = self._get_collection()
-        logging.info(collection.full_name, 'save', self._m__data)
         success = collection.save(self._m__data)
         if success:
             self._m__is_new = False
@@ -591,14 +599,12 @@ class MObject(object):
             query = new_query
 
         if _one:
-            logging.info(' - '.join([collection.full_name, 'find_one', str(query)]))
             response = collection.find_one(query, **kwargs)
             if response:
                 if not kwargs.get('raw'):
                     response = cls.load(**response)
                 return response
         else:
-            logging.info(' - '.join([collection.full_name, 'find', str(query)]))
             response = collection.find(query, **kwargs)
             if response:
                 if 'raw' in kwargs:
