@@ -1,3 +1,4 @@
+import logging
 from numbers import Number
 
 import bson
@@ -40,14 +41,32 @@ class _Relationship(object):
         related, foreign_key, key2 = cls.parse_attrs(active, attrs, key)
 
         if cls.TYPE == cls.HAS_MANY:
-            value = active.__getattr__('_id' if len(attrs) <= 2 else attrs[2], raw=True)
+            _k = '_id' if len(attrs) <= 2 else attrs[2]
+            value = active
+            for _key in _k.split('.'):
+                if hasattr(value, 'COLLECTION'):
+                    value = value.__getattr__(_key, raw=True)
+                else:
+                    value = value.get(_key)
         else:
-            value = active.__getattr__(key2, raw=True, default=[] if cls.TYPE == cls.BELONGS_TO_MANY else '')
+            value = active
+            for _key in key2.split('.'):
+                if hasattr(value, 'COLLECTION'):
+                    value = value.__getattr__(_key, raw=True, default=[] if cls.TYPE == cls.BELONGS_TO_MANY else '')
+                else:
+                    value = value.get(_key)
             if cls.TYPE == cls.BELONGS_TO_MANY:
                 value = {'$in': value}
 
         query = {foreign_key: value}
+        if not value:
+            return None
+
         data = related.find_one_by_(foreign_key, value) if cls.TYPE == cls.BELONGS_TO else related.find_by_(foreign_key, value)
+
+        if not data:
+            return None
+
         return cls(data, active, related, key, foreign_key)
 
     @classmethod
